@@ -1,24 +1,11 @@
-/* ****************************************************************************
-  This file is part of the game 'KJumpingCube'
+/*
+    This file is part of the game 'KJumpingCube'
 
-  Copyright (C) 1998-2000 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
+    SPDX-FileCopyrightText: 1998-2000 Matthias Kiefer <matthias.kiefer@gmx.de>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-**************************************************************************** */
 #include "kcubewidget.h"
 
 #include <QPainter>
